==> libreoffice_7.3.2.orig.tar.xz: libreoffice-7.3.2.2/vcl/osx/a11yvaluewrapper.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#ifndef INCLUDED_VCL_OSX_A11YVALUEWRAPPER_H
#define INCLUDED_VCL_OSX_A11YVALUEWRAPPER_H

#include <osx/salinst.h>
#include <osx/osxvcltypes.h>
#include <osx/a11ywrapper.h>

@interface AquaA11yValueWrapper : NSObject
{
}
+ (id)valueAttributeForElement:(AquaA11yWrapper*)wrapper;
+ (id)minValueAttributeForElement:(AquaA11yWrapper*)wrapper;
+ (id)maxValueAttributeForElement:(AquaA11yWrapper*)wrapper;
+ (void)addAttributeNamesTo:(NSMutableArray*)attributeNames;
+ (BOOL)isAttributeSettable:(NSString*)attribute forElement:(AquaA11yWrapper*)wrapper;
+ (void)setValueAttributeForElement:(AquaA11yWrapper*)wrapper to:(id)value;
@end

#endif // INCLUDED_VCL_OSX_A11YVALUEWRAPPER_H

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-25.8.2.2.tar.xz: libreoffice-25.8.2.2/vcl/osx/a11yvaluewrapper.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#pragma once

#include <osx/salinst.h>
#include <osx/osxvcltypes.h>
#include <osx/a11ywrapper.h>

@interface AquaA11yValueWrapper : NSObject
{
}
+ (id)valueAttributeForElement:(AquaA11yWrapper*)wrapper;
+ (id)minValueAttributeForElement:(AquaA11yWrapper*)wrapper;
+ (id)maxValueAttributeForElement:(AquaA11yWrapper*)wrapper;
+ (void)addAttributeNamesTo:(NSMutableArray*)attributeNames;
+ (BOOL)isAttributeSettable:(NSString*)attribute forElement:(AquaA11yWrapper*)wrapper;
+ (void)setValueAttributeForElement:(AquaA11yWrapper*)wrapper to:(id)value;
@end

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
